@@ -91,10 +91,8 @@ typedef struct myproxy_server_context_s
   int disable_usage_stats;          /* 0 if default usage metrics reporting OK */
   char *usage_stats_target;         /* Usage Statistics target string */
   myproxy_usage_t usage;
-#ifdef HAVE_VOMS
   int allow_voms_attribute_requests;/* Support VONAME/VOMSES in requests? */
   char *voms_userconf;              /* VOMS confuration file */
-#endif
 } myproxy_server_context_t;
 
 typedef struct myproxy_server_peer_t {
